@@ -7,7 +7,7 @@
 #### Principal Component Analysis p. 167-188.
 ################################
 
-pcr.tune <- function(y, x, M = 10, maxk = 50, seed = FALSE, ncores = 2) {
+pcr.tune <- function(y, x, M = 10, maxk = 50, seed = FALSE, ncores = 2, graph = TRUE) {
   ## y is the univariate dependent variable
   ## x contains the independent variables(s)
   ## M is the number of folds, set to 10 by default
@@ -17,7 +17,7 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, seed = FALSE, ncores = 2) {
   x <- as.matrix(x)
   n <- length(y)  ## sample size
   p <- ncol(x)  ## number of independent variables
-  if ( maxk > p ) maxk <- p  ## just a check
+  if ( maxk > p )  maxk <- p  ## just a check
   ## if seed==TRUE then the results will always be the same
   if (seed == TRUE)  set.seed(1234567)
   nu <- sample(1:n, min( n, round(n / M) * M ) )
@@ -48,7 +48,7 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, seed = FALSE, ncores = 2) {
     registerDoParallel(cl)
     er <- numeric(maxk)
     msp <- foreach::foreach(vim = 1:M, .combine = rbind, .export = "pcr") %dopar% {
-      if (seed == TRUE)  set.seed( vim:c(vim+10) ) ## If seed is TRUE the results
+      if (seed == TRUE)  set.seed( vim:c(vim + 10) ) ## If seed is TRUE the results
       ## will always be the same
       ytest <- as.vector( y[mat[, vim] ] )  ## test set dependent vars
       ytrain <- as.vector( y[-mat[, vim] ] )  ## train set dependent vars
@@ -65,10 +65,12 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, seed = FALSE, ncores = 2) {
   mspe <- colMeans(msp)
   bias <- msp[ ,which.min(mspe)] - apply(msp, 1, min)  ## TT estimate of bias
   estb <- mean( bias )  ## TT estimate of bias
-  plot(1:maxk, mspe, xlab = "Number of principal components",
-  ylab = "MSPE", type = "b")
+  if (graph == TRUE) {
+    plot(1:maxk, mspe, xlab = "Number of principal components",
+    ylab = "MSPE", type = "b")
+  }
   names(mspe) <- paste("PC", 1:maxk, sep = " ")
   performance <- c( min(mspe) + estb, estb)
   names(performance) <- c("MSPE", "Estimated bias")
-  list(mspe = mspe, k = which.min(mspe), performance = performance)
+  list(msp = msp, mspe = mspe, k = which.min(mspe), performance = performance)
 }
